diff src/dired.c @ 867:804517e16990

[xemacs-hg @ 2002-06-05 09:54:39 by ben] Textual renaming: text/char names abbrev.c, alloc.c, buffer.c, buffer.h, bytecode.c, callint.c, casefiddle.c, casetab.c, charset.h, chartab.c, chartab.h, cmds.c, console-gtk.h, console-msw.c, console-msw.h, console-stream.c, console-tty.c, console-x.c, console-x.h, console.h, data.c, device-msw.c, device-x.c, dialog-msw.c, dired-msw.c, dired.c, doc.c, doprnt.c, editfns.c, eldap.c, emodules.c, eval.c, event-Xt.c, event-gtk.c, event-msw.c, event-stream.c, event-unixoid.c, events.c, events.h, file-coding.c, file-coding.h, fileio.c, filelock.c, fns.c, font-lock.c, frame-gtk.c, frame-msw.c, frame-x.c, frame.c, glyphs-eimage.c, glyphs-msw.c, glyphs-x.c, glyphs.c, glyphs.h, gpmevent.c, gui-x.c, gui-x.h, gui.c, gui.h, hpplay.c, indent.c, insdel.c, insdel.h, intl-win32.c, keymap.c, line-number.c, line-number.h, lisp-disunion.h, lisp-union.h, lisp.h, lread.c, lrecord.h, lstream.c, lstream.h, md5.c, menubar-msw.c, menubar-x.c, menubar.c, minibuf.c, mule-ccl.c, mule-charset.c, mule-coding.c, mule-wnnfns.c, ndir.h, nt.c, objects-gtk.c, objects-gtk.h, objects-msw.c, objects-tty.c, objects-x.c, objects.c, objects.h, postgresql.c, print.c, process-nt.c, process-unix.c, process.c, procimpl.h, realpath.c, redisplay-gtk.c, redisplay-msw.c, redisplay-output.c, redisplay-tty.c, redisplay-x.c, redisplay.c, redisplay.h, regex.c, search.c, select-common.h, select-gtk.c, select-x.c, sound.h, symbols.c, syntax.c, syntax.h, sysdep.c, sysdep.h, sysdir.h, sysfile.h, sysproc.h, syspwd.h, systime.h, syswindows.h, termcap.c, tests.c, text.c, text.h, toolbar-common.c, tooltalk.c, ui-gtk.c, unexnt.c, unicode.c, win32.c: Text/char naming rationalization. [a] distinguish between "charptr" when it refers to operations on the pointer itself and when it refers to operations on text; and [b] use consistent naming for everything referring to internal format, i.e. Itext == text in internal format Ibyte == a byte in such text Ichar == a char as represented in internal character format thus e.g. set_charptr_emchar -> set_itext_ichar The pre and post tags on either side of this change are: pre-internal-format-textual-renaming post-internal-format-textual-renaming See the Internals Manual for details of exactly how this was done, how to handle the change in your workspace, etc.
author ben
date Wed, 05 Jun 2002 09:58:45 +0000
parents 2b6fa2618f76
children a8d8f419b459
line wrap: on
line diff
--- a/src/dired.c	Tue Jun 04 17:40:00 2002 +0000
+++ b/src/dired.c	Wed Jun 05 09:58:45 2002 +0000
@@ -78,7 +78,7 @@
   Lisp_Object handler;
   struct re_pattern_buffer *bufp = NULL;
   int speccount = specpdl_depth ();
-  Intbyte *statbuf, *statbuf_tail;
+  Ibyte *statbuf, *statbuf_tail;
 
   struct gcpro gcpro1, gcpro2;
   GCPRO2 (directory, list);
@@ -103,7 +103,7 @@
   directory = Ffile_name_as_directory (directory);
   directorylen = XSTRING_LENGTH (directory);
 
-  statbuf = (Intbyte *) ALLOCA (directorylen + MAXNAMLEN + 1);
+  statbuf = (Ibyte *) ALLOCA (directorylen + MAXNAMLEN + 1);
   memcpy (statbuf, XSTRING_DATA (directory), directorylen);
   statbuf_tail = statbuf + directorylen;
 
@@ -168,7 +168,7 @@
 
 	  {
 	    Lisp_Object name =
-	      make_string ((Intbyte *)dp->d_name, len);
+	      make_string ((Ibyte *)dp->d_name, len);
 	    if (!NILP (full))
 	      name = concat2 (directory, name);
 
@@ -250,7 +250,7 @@
   Bytecount len = NAMLEN (dp);
   Bytecount pos = XSTRING_LENGTH (directory);
   int value;
-  Intbyte *fullname = (Intbyte *) ALLOCA (len + pos + 2);
+  Ibyte *fullname = (Ibyte *) ALLOCA (len + pos + 2);
 
   memcpy (fullname, XSTRING_DATA (directory), pos);
   if (!IS_DIRECTORY_SEP (fullname[pos - 1]))
@@ -353,13 +353,13 @@
 	  Charcount cclen;
           int directoryp;
           int ignored_extension_p = 0;
-	  Intbyte *d_name;
+	  Ibyte *d_name;
 
 	  dp = qxe_readdir (d);
 	  if (!dp) break;
 
-	  /* Cast to Intbyte* is OK, as qxe_readdir() Mule-encapsulates.  */
-	  d_name = (Intbyte *) dp->d_name;
+	  /* Cast to Ibyte* is OK, as qxe_readdir() Mule-encapsulates.  */
+	  d_name = (Ibyte *) dp->d_name;
 	  len = NAMLEN (dp);
 	  cclen = bytecount_to_charcount (d_name, len);
 
@@ -402,7 +402,7 @@
 		      skip = cclen - string_char_length (elt);
 		      if (skip < 0) continue;
 
-		      if (0 > scmp (charptr_n_addr (d_name, skip),
+		      if (0 > scmp (itext_n_addr (d_name, skip),
 				    XSTRING_DATA (elt),
 				    string_char_length (elt)))
 			{
@@ -447,8 +447,8 @@
           else
             {
               Charcount compare = min (bestmatchsize, cclen);
-              Intbyte *p1 = XSTRING_DATA (bestmatch);
-              Intbyte *p2 = d_name;
+              Ibyte *p1 = XSTRING_DATA (bestmatch);
+              Ibyte *p2 = d_name;
               Charcount matchsize = scmp (p1, p2, compare);
 
               if (matchsize < 0)
@@ -489,7 +489,7 @@
               if (directoryp
                   && compare == matchsize
                   && bestmatchsize > matchsize
-                  && IS_ANY_SEP (charptr_emchar_n (p1, matchsize)))
+                  && IS_ANY_SEP (itext_ichar_n (p1, matchsize)))
                 matchsize++;
               bestmatchsize = matchsize;
             }
@@ -559,7 +559,7 @@
 
 struct user_name
 {
-  Intbyte *ptr;
+  Ibyte *ptr;
   Bytecount len;
 };
 
@@ -649,7 +649,7 @@
 	  DO_REALLOC (user_cache.user_names, user_cache.size,
 		      user_cache.length + 1, struct user_name);
 	  user_cache.user_names[user_cache.length].ptr =
-	    (Intbyte *) xstrdup (pwd->pw_name);
+	    (Ibyte *) xstrdup (pwd->pw_name);
 	  user_cache.user_names[user_cache.length].len = strlen (pwd->pw_name);
 	  user_cache.length++;
         }
@@ -717,7 +717,7 @@
 
   for (i = 0; i < user_cache.length; i++)
     {
-      Intbyte *u_name = user_cache.user_names[i].ptr;
+      Ibyte *u_name = user_cache.user_names[i].ptr;
       Bytecount len   = user_cache.user_names[i].len;
       /* scmp() works in chars, not bytes, so we have to compute this: */
       Charcount cclen = bytecount_to_charcount (u_name, len);
@@ -751,8 +751,8 @@
       else
         {
           Charcount compare = min (bestmatchsize, cclen);
-          Intbyte *p1 = XSTRING_DATA (bestmatch);
-          Intbyte *p2 = u_name;
+          Ibyte *p1 = XSTRING_DATA (bestmatch);
+          Ibyte *p2 = u_name;
           Charcount matchsize = scmp_1 (p1, p2, compare, 0);
 
           if (matchsize < 0)
@@ -776,7 +776,7 @@
 
 
 Lisp_Object
-make_directory_hash_table (const Intbyte *path)
+make_directory_hash_table (const Ibyte *path)
 {
   DIR *d;
   if ((d = qxe_opendir (path)))
@@ -789,8 +789,8 @@
 	{
 	  Bytecount len = NAMLEN (dp);
 	  if (DIRENTRY_NONEMPTY (dp))
-	    /* Cast to Intbyte* is OK, as qxe_readdir() Mule-encapsulates.  */
-	    Fputhash (make_string ((Intbyte *) dp->d_name, len), Qt, hash);
+	    /* Cast to Ibyte* is OK, as qxe_readdir() Mule-encapsulates.  */
+	    Fputhash (make_string ((Ibyte *) dp->d_name, len), Qt, hash);
 	}
       qxe_closedir (d);
       return hash;
@@ -867,7 +867,7 @@
 
 #if 0 /* #### shouldn't this apply to WIN32_NATIVE and maybe CYGWIN? */
   {
-    Intbyte *tmpnam = XSTRING_DATA (Ffile_name_nondirectory (filename));
+    Ibyte *tmpnam = XSTRING_DATA (Ffile_name_nondirectory (filename));
     Bytecount l = qxestrlen (tmpnam);
 
     if (l >= 5
@@ -907,7 +907,7 @@
   if (XINT (values[7]) != s.st_size)
     values[7] = make_int (-1);
   filemodestring (&s, modes);
-  values[8] = make_string ((Intbyte *) modes, 10);
+  values[8] = make_string ((Ibyte *) modes, 10);
 #if defined (BSD4_2) || defined (BSD4_3)	/* file gid will be dir gid */
   {
     struct stat sdir;